[![GitHub tag (latest SemVer)](https://img.shields.io/github/v/tag/bussilab/py-bussilab)](https://github.com/bussilab/py-bussilab/tags)
[![PyPI](https://img.shields.io/pypi/v/bussilab)](https://pypi.org/project/bussilab/)
[![Conda](https://img.shields.io/conda/v/bussilab/py-bussilab)](https://anaconda.org/bussilab/py-bussilab)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/bussilab)](https://pypi.org/project/bussilab/)

[![CI](https://github.com/bussilab/py-bussilab/workflows/CI/badge.svg)](https://github.com/bussilab/py-bussilab/actions?query=workflow%3ACI)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/bussilab/py-bussilab.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/bussilab/py-bussilab/context:python)
[![Total alerts](https://img.shields.io/lgtm/alerts/g/bussilab/py-bussilab.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/bussilab/py-bussilab/alerts/)
[![codecov](https://codecov.io/gh/bussilab/py-bussilab/branch/master/graph/badge.svg)](https://codecov.io/gh/bussilab/py-bussilab)

A package collecting a heterogeneous set of tools.

This package collects a number of tools that are useful enough to be distributed but too small to deserve being published as separate packages.
Source code is on [GitHub](https://github.com/bussilab/py-bussilab).
Documentation can be browsed at [this page](https://bussilab.github.io/doc-py-bussilab).

To install package and dependencies with pip:

```
pip install bussilab
```

To install package and dependencies with conda:

```
conda install -c conda-forge -c bussilab py-bussilab
```

To install dependencies with macports, see [documentation](https://bussilab.github.io/doc-py-bussilab).
